@@ -1,12 +1,12 @@
 package App::depak;
 
-our $DATE = '2015-08-01'; # DATE
-our $VERSION = '0.46'; # VERSION
+our $DATE = '2015-08-17'; # DATE
+our $VERSION = '0.47'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
-use Log::Any '$log';
+use Log::Any::IfLOG '$log';
 BEGIN { no warnings; $main::Log_Level = 'info' }
 
 use App::lcpan::Call qw(call_lcpan_script);
@@ -953,7 +953,7 @@ App::depak - Pack your dependencies onto your script file
 
 =head1 VERSION
 
-This document describes version 0.46 of App::depak (from Perl distribution App-depak), released on 2015-08-01.
+This document describes version 0.47 of App::depak (from Perl distribution App-depak), released on 2015-08-17.
 
 =head1 SYNOPSIS
 
