@@ -1,10 +1,10 @@
 package Perinci::CmdLine::depak;
 
-our $DATE = '2015-08-01'; # DATE
-our $VERSION = '0.46'; # VERSION
+our $DATE = '2015-08-17'; # DATE
+our $VERSION = '0.47'; # VERSION
 
 use 5.010;
-use Log::Any qw($log);
+use Log::Any::IfLOG qw($log);
 use parent qw(Perinci::CmdLine::Lite);
 
 sub hook_before_read_config_file {
@@ -65,7 +65,7 @@ Perinci::CmdLine::depak - Subclass of Perinci::CmdLine::Lite to set config_profi
 
 =head1 VERSION
 
-This document describes version 0.46 of Perinci::CmdLine::depak (from Perl distribution App-depak), released on 2015-08-01.
+This document describes version 0.47 of Perinci::CmdLine::depak (from Perl distribution App-depak), released on 2015-08-17.
 
 =head1 DESCRIPTION
 
